You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2017/03/14 18:36:01 UTC

[08/24] struts git commit: Marks param as a deprecated

Marks param as a deprecated


Project: http://git-wip-us.apache.org/repos/asf/struts/repo
Commit: http://git-wip-us.apache.org/repos/asf/struts/commit/741f3fa1
Tree: http://git-wip-us.apache.org/repos/asf/struts/tree/741f3fa1
Diff: http://git-wip-us.apache.org/repos/asf/struts/diff/741f3fa1

Branch: refs/heads/master
Commit: 741f3fa107eee331209e52477c1a007bfc5db755
Parents: 524343c
Author: Lukasz Lenart <lu...@apache.org>
Authored: Wed Mar 8 17:52:01 2017 +0100
Committer: Lukasz Lenart <lu...@apache.org>
Committed: Wed Mar 8 17:52:01 2017 +0100

----------------------------------------------------------------------
 .../apache/struts2/config/StrutsXmlConfigurationProvider.java    | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/struts/blob/741f3fa1/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java b/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java
index e39e475..75b8f64 100644
--- a/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java
+++ b/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java
@@ -62,10 +62,10 @@ public class StrutsXmlConfigurationProvider extends XmlConfigurationProvider {
      * Constructs the configuration provider
      *
      * @param filename The filename to look for
      * @param errorIfMissing If we should throw an exception if the file can't be found
      * @param ctx Our ServletContext
      */
-    public StrutsXmlConfigurationProvider(String filename, boolean errorIfMissing, ServletContext ctx) {
+    public StrutsXmlConfigurationProvider(String filename, @Deprecated boolean errorIfMissing, ServletContext ctx) {
         super(filename, errorIfMissing);
         this.servletContext = ctx;
         this.filename = filename;
@@ -62,10 +62,10 @@ public class StrutsXmlConfigurationProvider extends XmlConfigurationProvider {
      *
      * @param filename The filename to look for
-     * @param errorIfMissing If we should throw an exception if the file can't be found
+     * @param errorIfMissing If we should throw an exception if the file can't be found, @deprecated and should be dropped
      * @param ctx Our ServletContext
      */